import { Bit, BitVarying, Boolean, Box, ByteA, Character, CharacterVarying, Circle, Date, DateMultiRange, DateRange, Float4, Float8, Int2, Int4, Int4MultiRange, Int4Range, Int8, Int8MultiRange, Int8Range, Interval, JSON, Line, LineSegment, Money, Name, OID, Path, Point, Polygon, Text, Time, Timestamp, TimestampMultiRange, TimestampRange, TimestampTZ, TimestampTZMultiRange, TimestampTZRange, TimeTZ, UUID, } from "@postgresql-typed/parsers";
export function deserializer(object) {
    if (typeof object !== "object" || object === null)
        return object;
    if (Array.isArray(object))
        return object.map(element => deserializer(element));
    if (!("__pgtParserType" in object))
        return Object.fromEntries(Object.entries(object).map(([key, value]) => [key, deserializer(value)]));
    const { __pgtParserType, __pgtParserExtraData, ...rest } = object;
    switch (__pgtParserType) {
        case "bytea":
            return ByteA.from(rest);
        case "bit":
            return Bit.setN(Number(__pgtParserExtraData)).from(rest);
        case "bitVarying":
            return BitVarying.setN(Number(__pgtParserExtraData)).from(rest);
        case "boolean":
            return Boolean.from(rest);
        case "box":
            return Box.from(rest);
        case "character":
            return Character.setN(Number(__pgtParserExtraData)).from(rest);
        case "characterVarying":
            return CharacterVarying.setN(Number(__pgtParserExtraData)).from(rest);
        case "circle":
            return Circle.from(rest);
        case "date":
            return Date.from(rest);
        /* c8 ignore next 5 */
        // Not all postgres versions support this type, it is tested in higher versions.
        case "dateMultiRange":
            return DateMultiRange.from(rest);
        case "dateRange":
            return DateRange.from(rest);
        case "float4":
            return Float4.from(rest);
        case "float8":
            return Float8.from(rest);
        case "int2":
            return Int2.from(rest);
        case "int4":
            return Int4.from(rest);
        /* c8 ignore next 5 */
        // Not all postgres versions support this type, it is tested in higher versions.
        case "int4MultiRange":
            return Int4MultiRange.from(rest);
        case "int4Range":
            return Int4Range.from(rest);
        case "int8":
            return Int8.from(rest);
        /* c8 ignore next 5 */
        // Not all postgres versions support this type, it is tested in higher versions.
        case "int8MultiRange":
            return Int8MultiRange.from(rest);
        case "int8Range":
            return Int8Range.from(rest);
        case "interval":
            return Interval.from(rest);
        case "line":
            return Line.from(rest);
        case "lineSegment":
            return LineSegment.from(rest);
        case "money":
            return Money.from(rest);
        case "name":
            return Name.from(rest);
        case "oid":
            return OID.from(rest);
        case "path":
            return Path.from(rest);
        case "point":
            return Point.from(rest);
        case "polygon":
            return Polygon.from(rest);
        case "json":
            return JSON.from(rest);
        case "text":
            return Text.from(rest);
        case "time":
            return Time.from(rest);
        case "timestamp":
            return Timestamp.from(rest);
        /* c8 ignore next 5 */
        // Not all postgres versions support this type, it is tested in higher versions.
        case "timestampMultiRange":
            return TimestampMultiRange.from(rest);
        case "timestampRange":
            return TimestampRange.from(rest);
        case "timestampTZ":
            return TimestampTZ.from(rest);
        /* c8 ignore next 5 */
        // Not all postgres versions support this type, it is tested in higher versions.
        case "timestampTZMultiRange":
            return TimestampTZMultiRange.from(rest);
        case "timestampTZRange":
            return TimestampTZRange.from(rest);
        case "timeTZ":
            return TimeTZ.from(rest);
        case "uuid":
            return UUID.from(rest);
        /* c8 ignore next 5 */
        //! It should be impossible to reach this point, but we need to handle it to satisfy TypeScript.
        default:
            delete object.__pgtParserType;
            delete object.__pgtParserExtraData;
            return object;
    }
}
//# sourceMappingURL=deserializer.js.map